Load bindings from remake into the global environment (.GlobalEnv. The resulting objects are "active bindings" that when accessed will trigger a build of an object. Conversely, delete_bindings undoes this and deletes the bindings that remake made in the first place.

create_bindings(remake_file = "remake.yml")

delete_bindings(remake_file = "remake.yml")

Arguments

remake_file
Name of the remakefile to read. By default "remake.yml".