Plot the graph that remake generates.
diagram(..., remake_file = "remake.yml")
remake.yml).An htmlwidgets object, which are embeddable in all sorts
of things and print to the screen and seem very fancy. See the
grViz help for more information.
This is really just a placeholder, but I want this here early as
an indication of where the package is headed. Plus this is
something I have always wanted in make. Current version is
not tunable on purpose.