Run remake to build one or more targets.

make(target_names = NULL, ..., verbose = TRUE,
  allow_missing_packages = FALSE, remake_file = "remake.yml")

Arguments

target_names
Character vector of names of targets to build, or NULL to build the default target (if specified in the remakefile).
...
Additional future arguments, ignored for now. Practically this means that all other arguments must be specified by full name.
verbose
Controls whether remake is verbose or not. By default it is (TRUE), which prints out the name of each target as it is built/checked. This argument is passed to remake_verbose; valid options are TRUE, FALSE and also the result of calling remake_verbose.
allow_missing_packages
Allow missing packages when loading remake file?
remake_file
Name of the remakefile (by default remake.yml).