Construct an environment with remake target products, useful for debugging. Once you have an environment, you can attach it (yes, it is useful for something, but be careful to detach later), extract elements or browse it.

make_environment(target_names = character(0), dependencies = FALSE,
  copy_functions = TRUE, verbose = TRUE, allow_missing_packages = FALSE,
  remake_file = "remake.yml")

Arguments

target_names
Vector of target names to export. If omitted, then no targets are copied, though functions are still copied.
dependencies
Should the dependenciesof target_names also be copied over? Setting this to TRUE is equivalent to make_environment(list_dependencies(target_names, type="file")) but shorter to type.
copy_functions
Should functions be directly copied into the retuned environment? If FALSE, then the returned environment has an environment with functions as its parent. This is the same as the environment used by remake so don't assign anything in here! (This may change if it ends up being a point of fragility.)
verbose
Be verbose?
allow_missing_packages
Allow missing packages when loading remake file?
remake_file
Remake file to use, by default remake.yml.