Create a simple standalone script from a remake file.

make_script(target_names = NULL, verbose = FALSE, filename = NULL,
  remake_file = "remake.yml")

Arguments

target_names
Character vector of names of targets to build, or NULL to build the default target (if specified in the remakefile).
verbose
Be verbose when loading the remake file?
filename
A filename to save the resulting script into. If NULL (the default) then an a character vector is returned that can be inspected. It can also be sourced without writing to file using source_character.
remake_file
Name of the remakefile (by default remake.yml). This is passed to remake().
...
Additional future arguments, ignored for now. Practically this means that all other arguments must be specified by full name.