Fetch the last computed value from the remake database.
fetch(target_name, require_current = FALSE, verbose = TRUE, allow_missing_packages = FALSE, remake_file = "remake.yml")
TRUE and the targets
are not up-to-date, then an error will be thrown.TRUE.remake.yml)An R object.
The last computed value would be returned invisibly by
make, but this function provides a way of accessing values
without ever triggering a rebuild. As such, it's possible that the
target is not made, or is not current, so there are options for
controlling what to do in this case.
It is an error to use this function with file targets (but see
is_current for checking currentness) and
fetch_archive for extracting files from archives.